@@ -50,7 +50,7 @@ def render_fields(self, w, form, values):
                 self._main_display_fields, w, form)
 
 
-formrenderers.FormRenderer.button_bar_class = u'form-group col-lg-offset-2 col-lg-10'
+formrenderers.FormRenderer.button_bar_class = u'clearfix form-group'
 
 class ModalFormRenderer(formrenderers.FormRenderer):
     __regid__ = 'modal-form-renderer'
@@ -117,7 +117,7 @@ def render_help(self, form, field):
                  "and field as argument (%s)" % field, DeprecationWarning)
             descr = descr(form)
     if descr:
-        help.append('<p class="text-muted">%s</p>' % self._cw._(descr))
+        help.append('<p class="help-block">%s</p>' % self._cw._(descr))
     example = field.example_format(self._cw)
     if example:
         help.append('<p class="form-control-static">(%s: %s)</p>'
@@ -148,7 +148,7 @@ def error_message(self, form):
                     errormsg += templstr % '%s: %s' % (req._(field), err)
             if len(errors) > 1:
                 errormsg = '<ul>%s</ul>' % errormsg
-        return u'<div class="errorMessage alert">%s</div>' % errormsg
+        return u'<div class="alert alert-danger">%s</div>' % errormsg
     return u''
 
 
@@ -175,7 +175,7 @@ def _render_fields(self, fields, w, form):
         for field in fields:
             error = form.field_error(field)
             control = not hasattr(field, 'control_field') or field.control_field
-            w(u'<div class="form-group %s-%s_row %s">' % (field.name,
+            w(u'<div id="%s-%s_row" class="form-group %s">' % (field.name,
                                                           field.role,
                                                           'error' if error else ''))
             if self.display_label and field.label is not None:
@@ -184,9 +184,9 @@ def _render_fields(self, fields, w, form):
                         # but is used here because of
                         # 'form-horizontal' bootstrap 2.0.4 css
                         # backport
-                w(u'<div class="controls">')
+                w(u'<div class="col-md-9">')
             else:
-                w(u'<div class="controls no-margin">')
+                w(u'<div class="col-md-9 no-margin">')
             w(field.render(form, self))
             if error:
                 self.render_error(w, error)
@@ -204,7 +204,7 @@ def render_label(self, form, field):
         return u''
     label = formrenderers.field_label(form, field)
     attrs = {'for': field.dom_id(form)}
-    attrs['class'] = 'col-lg-2 control-label'
+    attrs['class'] = 'col-md-3 control-label'
     if field.required:
         attrs['class'] += ' required'
     return tags.label(label, **attrs)
@@ -251,8 +251,10 @@ def render_buttons(self, w, form):
     """let the form buttons be inside a div
     """
     if len(form.form_buttons) == 3:
-        w(u'<div> %s %s %s </div>' %
+        w(u'<div class="%s">\n' % self.button_bar_class)
+        w(u'%s %s %s' %
           tuple(button.render(form) for button in form.form_buttons))
+        w(u'</div>')
     else:
         super(formrenderers.EntityFormRenderer, self).render_buttons(w, form)
 
